summaryrefslogtreecommitdiffstats
path: root/chalk/ui/kobirdeyepanel.h
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/ui/kobirdeyepanel.h')
-rw-r--r--chalk/ui/kobirdeyepanel.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chalk/ui/kobirdeyepanel.h b/chalk/ui/kobirdeyepanel.h
index 24770b18..de280d9a 100644
--- a/chalk/ui/kobirdeyepanel.h
+++ b/chalk/ui/kobirdeyepanel.h
@@ -149,14 +149,14 @@ public:
* @param thumbnailProvider the class that creates the small image at the right
* zoomlevel
* @param canvas the place the document is painted.
* @param tqparent the tqparent widget
* @param name the TQObject name of this bird eye widget
* @param f the widget flags (@see TQWidget)
*/
KoBirdEyePanel( KoZoomAdapter * zoomListener,
KoThumbnailAdapter * thumbnailProvider,
KoCanvasAdapter * canvas,
- TQWidget * tqparent,
+ TQWidget * parent,
const char * name = 0,
WFlags f = 0 );
@@ -149,14 +149,14 @@ public:
* zoomlevel
* @param canvas the place the document is painted.
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
* @param name the TQObject name of this bird eye widget
* @param f the widget flags (@see TQWidget)